=======
Credits
=======

Development Lead
----------------

* Peter C DeWeirdt <petedeweirdt@gmail.com>

Contributors
------------

* Ruth E Hanna
* Mudra Hegde
* Zsofia Szegletes
* Annabel K Sangree
* Marissa N Feeley
* Audrey L Griffith


